# Change Log

## [Unreleased](https://github.com/JarryShaw/PyPCAPKit/tree/HEAD)

[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.5...HEAD)

**Fixed bugs:**

- 'bs4' dependency not installed via pip [\#31](https://github.com/JarryShaw/PyPCAPKit/issues/31)

## [v0.14.5](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.5) (2019-10-24)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.4...v0.14.5)

## [v0.14.4](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.4) (2019-09-01)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.3...v0.14.4)

## [v0.14.3](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.3) (2019-08-08)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.2...v0.14.3)

**Closed issues:**

- InfoClass instanciation calls `os.stat`, ruining performance [\#29](https://github.com/JarryShaw/PyPCAPKit/issues/29)

## [v0.14.2](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.2) (2019-03-28)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.1...v0.14.2)

**Merged pull requests:**

- New distribution \[0.14.2\] [\#28](https://github.com/JarryShaw/PyPCAPKit/pull/28) ([JarryShaw](https://github.com/JarryShaw))

## [v0.14.1](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.1) (2019-03-07)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.14.0...v0.14.1)

**Merged pull requests:**

- Remove .vscode once for good [\#27](https://github.com/JarryShaw/PyPCAPKit/pull/27) ([JarryShaw](https://github.com/JarryShaw))
-  New distribution \[0.14.1\] [\#26](https://github.com/JarryShaw/PyPCAPKit/pull/26) ([JarryShaw](https://github.com/JarryShaw))

## [v0.14.0](https://github.com/JarryShaw/PyPCAPKit/tree/v0.14.0) (2019-03-02)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.3.post2...v0.14.0)

**Merged pull requests:**

- New distribution \[0.14.0\] [\#25](https://github.com/JarryShaw/PyPCAPKit/pull/25) ([JarryShaw](https://github.com/JarryShaw))
- Add .dockerignore [\#24](https://github.com/JarryShaw/PyPCAPKit/pull/24) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.3.post2](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.3.post2) (2019-03-01)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.3.post1...v0.13.3.post2)

**Merged pull requests:**

- Fixed minor bugs in Makefile [\#23](https://github.com/JarryShaw/PyPCAPKit/pull/23) ([JarryShaw](https://github.com/JarryShaw))
- New distribution \[0.13.3.post2\] [\#22](https://github.com/JarryShaw/PyPCAPKit/pull/22) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.3.post1](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.3.post1) (2019-02-28)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.3...v0.13.3.post1)

**Merged pull requests:**

- New distribution \[0.13.3.post1\] [\#21](https://github.com/JarryShaw/PyPCAPKit/pull/21) ([JarryShaw](https://github.com/JarryShaw))
- Fixed minor bugs [\#20](https://github.com/JarryShaw/PyPCAPKit/pull/20) ([JarryShaw](https://github.com/JarryShaw))
- Fixed minor bugs [\#19](https://github.com/JarryShaw/PyPCAPKit/pull/19) ([JarryShaw](https://github.com/JarryShaw))
- Regular update [\#18](https://github.com/JarryShaw/PyPCAPKit/pull/18) ([JarryShaw](https://github.com/JarryShaw))
-  Fixed minor bugs in Makefile [\#17](https://github.com/JarryShaw/PyPCAPKit/pull/17) ([JarryShaw](https://github.com/JarryShaw))
- Renamed testbench submodules [\#16](https://github.com/JarryShaw/PyPCAPKit/pull/16) ([JarryShaw](https://github.com/JarryShaw))
- Update test branch [\#15](https://github.com/JarryShaw/PyPCAPKit/pull/15) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.3](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.3) (2019-02-26)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.2...v0.13.3)

**Merged pull requests:**

- New distribution \[0.13.3\] [\#14](https://github.com/JarryShaw/PyPCAPKit/pull/14) ([JarryShaw](https://github.com/JarryShaw))
- Fixed minor bugs in Makefile [\#13](https://github.com/JarryShaw/PyPCAPKit/pull/13) ([JarryShaw](https://github.com/JarryShaw))
- Update Makefile [\#12](https://github.com/JarryShaw/PyPCAPKit/pull/12) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.2](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.2) (2019-01-24)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.1...v0.13.2)

**Merged pull requests:**

- New distribution \[0.13.2\] [\#11](https://github.com/JarryShaw/PyPCAPKit/pull/11) ([JarryShaw](https://github.com/JarryShaw))
- Regular update [\#10](https://github.com/JarryShaw/PyPCAPKit/pull/10) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.1](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.1) (2019-01-23)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.0.post2...v0.13.1)

**Merged pull requests:**

- New distribution \[0.13.1\] [\#9](https://github.com/JarryShaw/PyPCAPKit/pull/9) ([JarryShaw](https://github.com/JarryShaw))

## [v0.13.0.post2](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.0.post2) (2018-12-12)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.0.post1...v0.13.0.post2)

## [v0.13.0.post1](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.0.post1) (2018-12-08)
[Full Changelog](https://github.com/JarryShaw/PyPCAPKit/compare/v0.13.0...v0.13.0.post1)

## [v0.13.0](https://github.com/JarryShaw/PyPCAPKit/tree/v0.13.0) (2018-12-08)
**Fixed bugs:**

- NameError: name 'packet' is not defined [\#2](https://github.com/JarryShaw/PyPCAPKit/issues/2)

**Merged pull requests:**

- Reconstruction accomplished [\#7](https://github.com/JarryShaw/PyPCAPKit/pull/7) ([JarryShaw](https://github.com/JarryShaw))
- Regular update [\#6](https://github.com/JarryShaw/PyPCAPKit/pull/6) ([JarryShaw](https://github.com/JarryShaw))
- Merge \[test/rc/protochain\] [\#5](https://github.com/JarryShaw/PyPCAPKit/pull/5) ([JarryShaw](https://github.com/JarryShaw))
- Fix typo in README [\#1](https://github.com/JarryShaw/PyPCAPKit/pull/1) ([gousaiyang](https://github.com/gousaiyang))



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*